@@ -9,8 +9,7 @@ from bpkio_api.helpers.objects import find_duplicates_of
 from bpkio_api.helpers.search import SearchMethod, search_array_with_filters
 from bpkio_api.models import Sources as S
 from bpkio_api.response_handler import postprocess_response
-from uplink import (Body, Query, delete, get, json, post, put,
-                    response_handler, returns)
+from uplink import Body, Query, delete, get, json, post, put, response_handler, returns
 
 from .enums import UpsertOperationType
 
@@ -54,8 +53,10 @@ class SourcesApi(BpkioSdkConsumer):
         """Get a partial list of Sources"""
 
     @returns.json()
-    @get("sources/{type}/check")
-    def check(self, type: S.SourceType, url: Query) -> List[S.SourceCheckResult]:
+    @post("sources/{type}/check")
+    def check(
+        self, type: S.SourceType, body: Body(type=S.SourceStatusCheck)
+    ) -> S.SourceStatusCheckResult:
         """Check a URL for compliance as a Source"""
 
     # === Helpers ===
@@ -246,15 +247,31 @@ class SourcesApi(BpkioSdkConsumer):
                         updated_resource = self._update(existing_resource.id, source)
                         return (updated_resource, UpsertOperationType.UPDATED)
 
-    def check_by_id(self, source_id: int) -> List[S.SourceCheckResult]:
+    def check_by_id(self, source_id: int) -> List[S.SourceStatusCheckResult]:
         source = self.retrieve(source_id=source_id)
 
         if source:
             url = source.url
+
+            # Ad proxy cannot be checked
+            if not url.startswith("http"):
+                raise ValueError("This type of source cannot be checked")
+
             if source.type == S.SourceType.ASSET_CATALOG:
                 url = url + source.assetSample
 
-            return self.check(type=source.type, url=url)
+            payload = S.SourceStatusCheck(url=url)
+            if (
+                hasattr(source, "origin")
+                and source.origin
+                and len(source.origin.customHeaders)
+            ):
+                payload.origin = source.origin
+
+            return self.check(
+                type=source.type,
+                body=payload,
+            )
 
 
 # === ASSET SOURCES ===
